/*
 * This file is part of gspell, a spell-checking library.
 *
 * Copyright 2015 - Sébastien Wilmet <swilmet@gnome.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GSPELL_H
#define GSPELL_H

#define GSPELL_H_INSIDE

#include <gspell/gspell-checker.h>
#include <gspell/gspell-checker-dialog.h>
#include <gspell/gspell-entry.h>
#include <gspell/gspell-entry-buffer.h>
#include <gspell/gspell-language.h>
#include <gspell/gspell-language-chooser.h>
#include <gspell/gspell-language-chooser-button.h>
#include <gspell/gspell-language-chooser-dialog.h>
#include <gspell/gspell-navigator.h>
#include <gspell/gspell-navigator-text-view.h>
#include <gspell/gspell-text-buffer.h>
#include <gspell/gspell-text-view.h>

#include <gspell/gspell-enum-types.h>

#undef GSPELL_H_INSIDE

#endif /* GSPELL_H */
